"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CodeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CodeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NOCODE: _CodeType.ValueType  # 0
    """"""
    CODE264: _CodeType.ValueType  # 1
    """H264"""
    CODE265: _CodeType.ValueType  # 2
    """H265"""
    CODEAV1: _CodeType.ValueType  # 3
    """AV1"""

class CodeType(_CodeType, metaclass=_CodeTypeEnumTypeWrapper):
    """视频编码"""

NOCODE: CodeType.ValueType  # 0
""""""
CODE264: CodeType.ValueType  # 1
"""H264"""
CODE265: CodeType.ValueType  # 2
"""H265"""
CODEAV1: CodeType.ValueType  # 3
"""AV1"""
global___CodeType = CodeType

class _ConfType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ConfTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ConfType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoType: _ConfType.ValueType  # 0
    FLIPCONF: _ConfType.ValueType  # 1
    CASTCONF: _ConfType.ValueType  # 2
    FEEDBACK: _ConfType.ValueType  # 3
    SUBTITLE: _ConfType.ValueType  # 4
    PLAYBACKRATE: _ConfType.ValueType  # 5
    TIMEUP: _ConfType.ValueType  # 6
    PLAYBACKMODE: _ConfType.ValueType  # 7
    SCALEMODE: _ConfType.ValueType  # 8
    BACKGROUNDPLAY: _ConfType.ValueType  # 9
    LIKE: _ConfType.ValueType  # 10
    DISLIKE: _ConfType.ValueType  # 11
    COIN: _ConfType.ValueType  # 12
    ELEC: _ConfType.ValueType  # 13
    SHARE: _ConfType.ValueType  # 14
    SCREENSHOT: _ConfType.ValueType  # 15
    LOCKSCREEN: _ConfType.ValueType  # 16
    RECOMMEND: _ConfType.ValueType  # 17
    PLAYBACKSPEED: _ConfType.ValueType  # 18
    DEFINITION: _ConfType.ValueType  # 19
    SELECTIONS: _ConfType.ValueType  # 20
    NEXT: _ConfType.ValueType  # 21
    EDITDM: _ConfType.ValueType  # 22
    SMALLWINDOW: _ConfType.ValueType  # 23
    SHAKE: _ConfType.ValueType  # 24
    OUTERDM: _ConfType.ValueType  # 25
    INNERDM: _ConfType.ValueType  # 26
    PANORAMA: _ConfType.ValueType  # 27
    DOLBY: _ConfType.ValueType  # 28
    COLORFILTER: _ConfType.ValueType  # 29
    LOSSLESS: _ConfType.ValueType  # 30
    FREYAENTER: _ConfType.ValueType  # 31
    FREYAFULLENTER: _ConfType.ValueType  # 32
    SKIPOPED: _ConfType.ValueType  # 33
    RECORDSCREEN: _ConfType.ValueType  # 34
    DUBBING: _ConfType.ValueType  # 35
    LISTEN: _ConfType.ValueType  # 36

class ConfType(_ConfType, metaclass=_ConfTypeEnumTypeWrapper):
    """功能类型"""

NoType: ConfType.ValueType  # 0
FLIPCONF: ConfType.ValueType  # 1
CASTCONF: ConfType.ValueType  # 2
FEEDBACK: ConfType.ValueType  # 3
SUBTITLE: ConfType.ValueType  # 4
PLAYBACKRATE: ConfType.ValueType  # 5
TIMEUP: ConfType.ValueType  # 6
PLAYBACKMODE: ConfType.ValueType  # 7
SCALEMODE: ConfType.ValueType  # 8
BACKGROUNDPLAY: ConfType.ValueType  # 9
LIKE: ConfType.ValueType  # 10
DISLIKE: ConfType.ValueType  # 11
COIN: ConfType.ValueType  # 12
ELEC: ConfType.ValueType  # 13
SHARE: ConfType.ValueType  # 14
SCREENSHOT: ConfType.ValueType  # 15
LOCKSCREEN: ConfType.ValueType  # 16
RECOMMEND: ConfType.ValueType  # 17
PLAYBACKSPEED: ConfType.ValueType  # 18
DEFINITION: ConfType.ValueType  # 19
SELECTIONS: ConfType.ValueType  # 20
NEXT: ConfType.ValueType  # 21
EDITDM: ConfType.ValueType  # 22
SMALLWINDOW: ConfType.ValueType  # 23
SHAKE: ConfType.ValueType  # 24
OUTERDM: ConfType.ValueType  # 25
INNERDM: ConfType.ValueType  # 26
PANORAMA: ConfType.ValueType  # 27
DOLBY: ConfType.ValueType  # 28
COLORFILTER: ConfType.ValueType  # 29
LOSSLESS: ConfType.ValueType  # 30
FREYAENTER: ConfType.ValueType  # 31
FREYAFULLENTER: ConfType.ValueType  # 32
SKIPOPED: ConfType.ValueType  # 33
RECORDSCREEN: ConfType.ValueType  # 34
DUBBING: ConfType.ValueType  # 35
LISTEN: ConfType.ValueType  # 36
global___ConfType = ConfType

class _DrmTechType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DrmTechTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DrmTechType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_DRM: _DrmTechType.ValueType  # 0
    """"""
    FAIR_PLAY: _DrmTechType.ValueType  # 1
    """"""
    WIDE_VINE: _DrmTechType.ValueType  # 2
    """"""
    BILI_DRM: _DrmTechType.ValueType  # 3
    """哔哩哔哩自研DRM"""

class DrmTechType(_DrmTechType, metaclass=_DrmTechTypeEnumTypeWrapper):
    """DRM类型"""

UNKNOWN_DRM: DrmTechType.ValueType  # 0
""""""
FAIR_PLAY: DrmTechType.ValueType  # 1
""""""
WIDE_VINE: DrmTechType.ValueType  # 2
""""""
BILI_DRM: DrmTechType.ValueType  # 3
"""哔哩哔哩自研DRM"""
global___DrmTechType = DrmTechType

class _PlayErr:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayErrEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayErr.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoErr: _PlayErr.ValueType  # 0
    """"""
    WithMultiDeviceLoginErr: _PlayErr.ValueType  # 1
    """管控类型的错误码"""

class PlayErr(_PlayErr, metaclass=_PlayErrEnumTypeWrapper):
    """错误码"""

NoErr: PlayErr.ValueType  # 0
""""""
WithMultiDeviceLoginErr: PlayErr.ValueType  # 1
"""管控类型的错误码"""
global___PlayErr = PlayErr

class _UnsupportScene:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UnsupportSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UnsupportScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_SCENE: _UnsupportScene.ValueType  # 0
    """"""
    PREMIERE: _UnsupportScene.ValueType  # 1
    """"""

class UnsupportScene(_UnsupportScene, metaclass=_UnsupportSceneEnumTypeWrapper):
    """"""

UNKNOWN_SCENE: UnsupportScene.ValueType  # 0
""""""
PREMIERE: UnsupportScene.ValueType  # 1
""""""
global___UnsupportScene = UnsupportScene

class _VideoType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _VideoType.ValueType  # 0
    UGC: _VideoType.ValueType  # 1
    """用户生成内容"""
    PGC: _VideoType.ValueType  # 2
    """专业生产内容"""

class VideoType(_VideoType, metaclass=_VideoTypeEnumTypeWrapper):
    """视频类型"""

UNKNOWN: VideoType.ValueType  # 0
UGC: VideoType.ValueType  # 1
"""用户生成内容"""
PGC: VideoType.ValueType  # 2
"""专业生产内容"""
global___VideoType = VideoType

@typing_extensions.final
class ArcConf(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_SUPPORT_FIELD_NUMBER: builtins.int
    DISABLE_FIELD_NUMBER: builtins.int
    EXTRA_CONNENT_FIELD_NUMBER: builtins.int
    UNSUPPORT_SCENE_FIELD_NUMBER: builtins.int
    is_support: builtins.bool
    disable: builtins.bool
    @property
    def extra_connent(self) -> global___ExtraContent: ...
    @property
    def unsupport_scene(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        is_support: builtins.bool = ...,
        disable: builtins.bool = ...,
        extra_connent: global___ExtraContent | None = ...,
        unsupport_scene: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra_connent", b"extra_connent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable", b"disable", "extra_connent", b"extra_connent", "is_support", b"is_support", "unsupport_scene", b"unsupport_scene"]) -> None: ...

global___ArcConf = ArcConf

@typing_extensions.final
class ConfValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SWITCH_VAL_FIELD_NUMBER: builtins.int
    SELECTED_VAL_FIELD_NUMBER: builtins.int
    switch_val: builtins.int
    """dash流"""
    selected_val: builtins.int
    """分段流"""
    def __init__(
        self,
        *,
        switch_val: builtins.int = ...,
        selected_val: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["selected_val", b"selected_val", "switch_val", b"switch_val", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["selected_val", b"selected_val", "switch_val", b"switch_val", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value", b"value"]) -> typing_extensions.Literal["switch_val", "selected_val"] | None: ...

global___ConfValue = ConfValue

@typing_extensions.final
class DeviceConf(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONF_VALUE_FIELD_NUMBER: builtins.int
    @property
    def conf_value(self) -> global___ConfValue: ...
    def __init__(
        self,
        *,
        conf_value: global___ConfValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conf_value", b"conf_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conf_value", b"conf_value"]) -> None: ...

global___DeviceConf = DeviceConf

@typing_extensions.final
class ExtraContent(google.protobuf.message.Message):
    """? 错误码补充信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_REASON_FIELD_NUMBER: builtins.int
    DISABLE_CODE_FIELD_NUMBER: builtins.int
    disable_reason: builtins.str
    """"""
    disable_code: builtins.int
    """"""
    def __init__(
        self,
        *,
        disable_reason: builtins.str = ...,
        disable_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_code", b"disable_code", "disable_reason", b"disable_reason"]) -> None: ...

global___ExtraContent = ExtraContent

@typing_extensions.final
class History(google.protobuf.message.Message):
    """播放历史"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRESS_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    LAST_PLAY_CID_FIELD_NUMBER: builtins.int
    progress: builtins.int
    """播放进度"""
    toast: builtins.str
    """"""
    last_play_cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        progress: builtins.int = ...,
        toast: builtins.str = ...,
        last_play_cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_play_cid", b"last_play_cid", "progress", b"progress", "toast", b"toast"]) -> None: ...

global___History = History

@typing_extensions.final
class PlayDeviceConf(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ArcConfsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___DeviceConf: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___DeviceConf | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARC_CONFS_FIELD_NUMBER: builtins.int
    @property
    def arc_confs(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___DeviceConf]: ...
    def __init__(
        self,
        *,
        arc_confs: collections.abc.Mapping[builtins.int, global___DeviceConf] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_confs", b"arc_confs"]) -> None: ...

global___PlayDeviceConf = PlayDeviceConf

@typing_extensions.final
class Scheme(google.protobuf.message.Message):
    """方案"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ActionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Scheme._ActionType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Scheme._ActionType.ValueType  # 0
        SHOW_TOAST: Scheme._ActionType.ValueType  # 1

    class ActionType(_ActionType, metaclass=_ActionTypeEnumTypeWrapper): ...
    UNKNOWN: Scheme.ActionType.ValueType  # 0
    SHOW_TOAST: Scheme.ActionType.ValueType  # 1

    ACTION_TYPE_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    action_type: global___Scheme.ActionType.ValueType
    toast: builtins.str
    def __init__(
        self,
        *,
        action_type: global___Scheme.ActionType.ValueType = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_type", b"action_type", "toast", b"toast"]) -> None: ...

global___Scheme = Scheme

@typing_extensions.final
class Stream(google.protobuf.message.Message):
    """视频流信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_INFO_FIELD_NUMBER: builtins.int
    DASH_VIDEO_FIELD_NUMBER: builtins.int
    SEGMENT_VIDEO_FIELD_NUMBER: builtins.int
    @property
    def stream_info(self) -> global___StreamInfo:
        """元数据"""
    @property
    def dash_video(self) -> global___DashVideo:
        """dash流"""
    @property
    def segment_video(self) -> global___SegmentVideo:
        """分段流"""
    def __init__(
        self,
        *,
        stream_info: global___StreamInfo | None = ...,
        dash_video: global___DashVideo | None = ...,
        segment_video: global___SegmentVideo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "dash_video", b"dash_video", "segment_video", b"segment_video", "stream_info", b"stream_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "dash_video", b"dash_video", "segment_video", b"segment_video", "stream_info", b"stream_info"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["dash_video", "segment_video"] | None: ...

global___Stream = Stream

@typing_extensions.final
class StreamInfo(google.protobuf.message.Message):
    """视频流信息: 元数据"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ERR_CODE_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    NEED_VIP_FIELD_NUMBER: builtins.int
    NEED_LOGIN_FIELD_NUMBER: builtins.int
    INTACT_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    NEW_DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_DESC_FIELD_NUMBER: builtins.int
    SUPERSCRIPT_FIELD_NUMBER: builtins.int
    VIP_FREE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    SUPPORT_DRM_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """清晰度"""
    format: builtins.str
    """格式"""
    description: builtins.str
    """格式描述"""
    err_code: builtins.int
    """错误码"""
    @property
    def limit(self) -> global___StreamLimit:
        """不满足条件信息"""
    need_vip: builtins.bool
    """是否需要vip"""
    need_login: builtins.bool
    """是否需要登录"""
    intact: builtins.bool
    """是否完整"""
    no_rexcode: builtins.bool
    """是否非全二压"""
    attribute: builtins.int
    """清晰度属性位"""
    new_description: builtins.str
    """新版格式描述"""
    display_desc: builtins.str
    """格式文字"""
    superscript: builtins.str
    """新版格式描述备注"""
    vip_free: builtins.bool
    """"""
    subtitle: builtins.str
    """"""
    @property
    def scheme(self) -> global___Scheme:
        """方案"""
    support_drm: builtins.bool
    """支持drm"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        description: builtins.str = ...,
        err_code: builtins.int = ...,
        limit: global___StreamLimit | None = ...,
        need_vip: builtins.bool = ...,
        need_login: builtins.bool = ...,
        intact: builtins.bool = ...,
        no_rexcode: builtins.bool = ...,
        attribute: builtins.int = ...,
        new_description: builtins.str = ...,
        display_desc: builtins.str = ...,
        superscript: builtins.str = ...,
        vip_free: builtins.bool = ...,
        subtitle: builtins.str = ...,
        scheme: global___Scheme | None = ...,
        support_drm: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limit", b"limit", "scheme", b"scheme"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "description", b"description", "display_desc", b"display_desc", "err_code", b"err_code", "format", b"format", "intact", b"intact", "limit", b"limit", "need_login", b"need_login", "need_vip", b"need_vip", "new_description", b"new_description", "no_rexcode", b"no_rexcode", "quality", b"quality", "scheme", b"scheme", "subtitle", b"subtitle", "superscript", b"superscript", "support_drm", b"support_drm", "vip_free", b"vip_free"]) -> None: ...

global___StreamInfo = StreamInfo

@typing_extensions.final
class DashItem(google.protobuf.message.Message):
    """Dash条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    WIDEVINE_PSSH_FIELD_NUMBER: builtins.int
    id: builtins.int
    """清晰度"""
    base_url: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    bandwidth: builtins.int
    """带宽"""
    codecid: builtins.int
    """编码id"""
    md5: builtins.str
    """md5"""
    size: builtins.int
    """大小"""
    frame_rate: builtins.str
    """帧率"""
    widevine_pssh: builtins.str
    """DRM密钥"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        base_url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: builtins.str = ...,
        size: builtins.int = ...,
        frame_rate: builtins.str = ...,
        widevine_pssh: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url", b"backup_url", "bandwidth", b"bandwidth", "base_url", b"base_url", "codecid", b"codecid", "frame_rate", b"frame_rate", "id", b"id", "md5", b"md5", "size", b"size", "widevine_pssh", b"widevine_pssh"]) -> None: ...

global___DashItem = DashItem

@typing_extensions.final
class DashVideo(google.protobuf.message.Message):
    """视频流信息: dash流"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    AUDIO_ID_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    WIDEVINE_PSSH_FIELD_NUMBER: builtins.int
    base_url: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    bandwidth: builtins.int
    """带宽"""
    codecid: builtins.int
    """编码id"""
    md5: builtins.str
    """md5"""
    size: builtins.int
    """大小"""
    audio_id: builtins.int
    """伴音质量id"""
    no_rexcode: builtins.bool
    """是否非全二压"""
    frame_rate: builtins.str
    """帧率"""
    width: builtins.int
    """宽"""
    height: builtins.int
    """高"""
    widevine_pssh: builtins.str
    """DRM密钥"""
    def __init__(
        self,
        *,
        base_url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: builtins.str = ...,
        size: builtins.int = ...,
        audio_id: builtins.int = ...,
        no_rexcode: builtins.bool = ...,
        frame_rate: builtins.str = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        widevine_pssh: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_id", b"audio_id", "backup_url", b"backup_url", "bandwidth", b"bandwidth", "base_url", b"base_url", "codecid", b"codecid", "frame_rate", b"frame_rate", "height", b"height", "md5", b"md5", "no_rexcode", b"no_rexcode", "size", b"size", "widevine_pssh", b"widevine_pssh", "width", b"width"]) -> None: ...

global___DashVideo = DashVideo

@typing_extensions.final
class SegmentVideo(google.protobuf.message.Message):
    """视频流信息: 分段流"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENT_FIELD_NUMBER: builtins.int
    @property
    def segment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseUrl]: ...
    def __init__(
        self,
        *,
        segment: collections.abc.Iterable[global___ResponseUrl] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["segment", b"segment"]) -> None: ...

global___SegmentVideo = SegmentVideo

@typing_extensions.final
class ResponseUrl(google.protobuf.message.Message):
    """分段流条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    order: builtins.int
    """分段序号"""
    length: builtins.int
    """分段时长"""
    size: builtins.int
    """分段大小"""
    url: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    md5: builtins.str
    """md5"""
    def __init__(
        self,
        *,
        order: builtins.int = ...,
        length: builtins.int = ...,
        size: builtins.int = ...,
        url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        md5: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url", b"backup_url", "length", b"length", "md5", b"md5", "order", b"order", "size", b"size", "url", b"url"]) -> None: ...

global___ResponseUrl = ResponseUrl

@typing_extensions.final
class ResponseDash(google.protobuf.message.Message):
    """Dash Response, 未使用"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def video(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]: ...
    @property
    def audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]: ...
    def __init__(
        self,
        *,
        video: collections.abc.Iterable[global___DashItem] | None = ...,
        audio: collections.abc.Iterable[global___DashItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "video", b"video"]) -> None: ...

global___ResponseDash = ResponseDash

@typing_extensions.final
class StreamLimit(google.protobuf.message.Message):
    """视频流信息: 流媒体元数据: 清晰度不满足条件信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    msg: builtins.str
    """提示信息"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg", b"msg", "title", b"title", "uri", b"uri"]) -> None: ...

global___StreamLimit = StreamLimit

@typing_extensions.final
class VideoVod(google.protobuf.message.Message):
    """播放页信息-请求: 音视频VOD"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    VOICE_BALANCE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """视频aid"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    prefer_codec_type: global___CodeType.ValueType
    """视频编码"""
    voice_balance: builtins.int
    """响度均衡"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        prefer_codec_type: global___CodeType.ValueType = ...,
        voice_balance: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "download", b"download", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "prefer_codec_type", b"prefer_codec_type", "qn", b"qn", "voice_balance", b"voice_balance"]) -> None: ...

global___VideoVod = VideoVod

@typing_extensions.final
class VodInfo(google.protobuf.message.Message):
    """播放页信息-响应: VOD音视频信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    TIMELENGTH_FIELD_NUMBER: builtins.int
    VIDEO_CODECID_FIELD_NUMBER: builtins.int
    STREAM_LIST_FIELD_NUMBER: builtins.int
    DASH_AUDIO_FIELD_NUMBER: builtins.int
    DOLBY_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    LOSS_LESS_ITEM_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """视频清晰度"""
    format: builtins.str
    """视频格式"""
    timelength: builtins.int
    """视频时长"""
    video_codecid: builtins.int
    """视频编码id"""
    @property
    def stream_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stream]:
        """视频流"""
    @property
    def dash_audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """伴音流"""
    @property
    def dolby(self) -> global___DolbyItem:
        """杜比伴音流"""
    @property
    def volume(self) -> global___VolumeInfo:
        """响度均衡操作信息"""
    @property
    def loss_less_item(self) -> global___LossLessItem:
        """HIRES伴音流信息"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        timelength: builtins.int = ...,
        video_codecid: builtins.int = ...,
        stream_list: collections.abc.Iterable[global___Stream] | None = ...,
        dash_audio: collections.abc.Iterable[global___DashItem] | None = ...,
        dolby: global___DolbyItem | None = ...,
        volume: global___VolumeInfo | None = ...,
        loss_less_item: global___LossLessItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dolby", b"dolby", "loss_less_item", b"loss_less_item", "volume", b"volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dash_audio", b"dash_audio", "dolby", b"dolby", "format", b"format", "loss_less_item", b"loss_less_item", "quality", b"quality", "stream_list", b"stream_list", "timelength", b"timelength", "video_codecid", b"video_codecid", "volume", b"volume"]) -> None: ...

global___VodInfo = VodInfo

@typing_extensions.final
class DolbyItem(google.protobuf.message.Message):
    """杜比伴音流信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DolbyItem._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: DolbyItem._Type.ValueType  # 0
        """NONE"""
        COMMON: DolbyItem._Type.ValueType  # 1
        """普通杜比音效"""
        ATMOS: DolbyItem._Type.ValueType  # 2
        """全景杜比音效"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """杜比类型"""

    NONE: DolbyItem.Type.ValueType  # 0
    """NONE"""
    COMMON: DolbyItem.Type.ValueType  # 1
    """普通杜比音效"""
    ATMOS: DolbyItem.Type.ValueType  # 2
    """全景杜比音效"""

    TYPE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    type: global___DolbyItem.Type.ValueType
    """杜比类型"""
    @property
    def audio(self) -> global___DashItem:
        """音频流"""
    def __init__(
        self,
        *,
        type: global___DolbyItem.Type.ValueType = ...,
        audio: global___DashItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "type", b"type"]) -> None: ...

global___DolbyItem = DolbyItem

@typing_extensions.final
class LossLessItem(google.protobuf.message.Message):
    """HIRES伴音流信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_LOSSLESS_AUDIO_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    NEED_VIP_FIELD_NUMBER: builtins.int
    is_lossless_audio: builtins.bool
    """是否为hires"""
    @property
    def audio(self) -> global___DashItem:
        """音频流信息"""
    need_vip: builtins.bool
    """是否需要大会员"""
    def __init__(
        self,
        *,
        is_lossless_audio: builtins.bool = ...,
        audio: global___DashItem | None = ...,
        need_vip: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "is_lossless_audio", b"is_lossless_audio", "need_vip", b"need_vip"]) -> None: ...

global___LossLessItem = LossLessItem

@typing_extensions.final
class VolumeInfo(google.protobuf.message.Message):
    """响度均衡操作信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEASURED_I_FIELD_NUMBER: builtins.int
    MEASURED_LRA_FIELD_NUMBER: builtins.int
    MEASURED_TP_FIELD_NUMBER: builtins.int
    MEASURED_THRESHOLD_FIELD_NUMBER: builtins.int
    TARGET_OFFSET_FIELD_NUMBER: builtins.int
    TARGET_I_FIELD_NUMBER: builtins.int
    TARGET_TP_FIELD_NUMBER: builtins.int
    measured_i: builtins.float
    """Measured integrated loudness 实际综合响度"""
    measured_lra: builtins.float
    """Measured loudness range 实际响度范围"""
    measured_tp: builtins.float
    """Measured true peak 实际响度真峰值"""
    measured_threshold: builtins.float
    """Measured threshold 实际响度阈值"""
    target_offset: builtins.float
    """Target offset gain(Gain is applied before the true-peak limiter) 目标增益Offset(增益在真实峰值限制器之前应用)"""
    target_i: builtins.float
    """Target integrated loudness 目标综合响度"""
    target_tp: builtins.float
    """Target true peak 目标响度真峰值"""
    def __init__(
        self,
        *,
        measured_i: builtins.float = ...,
        measured_lra: builtins.float = ...,
        measured_tp: builtins.float = ...,
        measured_threshold: builtins.float = ...,
        target_offset: builtins.float = ...,
        target_i: builtins.float = ...,
        target_tp: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["measured_i", b"measured_i", "measured_lra", b"measured_lra", "measured_threshold", b"measured_threshold", "measured_tp", b"measured_tp", "target_i", b"target_i", "target_offset", b"target_offset", "target_tp", b"target_tp"]) -> None: ...

global___VolumeInfo = VolumeInfo

@typing_extensions.final
class PlayArc(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_TYPE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    DRM_TECH_TYPE_FIELD_NUMBER: builtins.int
    video_type: global___VideoType.ValueType
    aid: builtins.int
    cid: builtins.int
    drm_tech_type: global___DrmTechType.ValueType
    def __init__(
        self,
        *,
        video_type: global___VideoType.ValueType = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        drm_tech_type: global___DrmTechType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "drm_tech_type", b"drm_tech_type", "video_type", b"video_type"]) -> None: ...

global___PlayArc = PlayArc

@typing_extensions.final
class PlayArcConf(google.protobuf.message.Message):
    """播放页信息-响应: PlayArcConf"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ArcConfsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___PlayArc: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___PlayArc | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARC_CONFS_FIELD_NUMBER: builtins.int
    @property
    def arc_confs(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___PlayArc]: ...
    def __init__(
        self,
        *,
        arc_confs: collections.abc.Mapping[builtins.int, global___PlayArc] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_confs", b"arc_confs"]) -> None: ...

global___PlayArcConf = PlayArcConf

@typing_extensions.final
class QnTrialButton(google.protobuf.message.Message):
    """高画质试看信息: 按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    text: builtins.str
    link: builtins.str
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["link", b"link", "text", b"text"]) -> None: ...

global___QnTrialButton = QnTrialButton

@typing_extensions.final
class QnTrialInfo(google.protobuf.message.Message):
    """播放页信息-响应: 高画质试看信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIAL_ABLE_FIELD_NUMBER: builtins.int
    REMAINING_TIMES_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    TIME_LENGTH_FIELD_NUMBER: builtins.int
    START_TOAST_FIELD_NUMBER: builtins.int
    END_TOAST_FIELD_NUMBER: builtins.int
    QUALITY_OPEN_TIP_BTN_FIELD_NUMBER: builtins.int
    trial_able: builtins.bool
    """能否试看高画质"""
    remaining_times: builtins.int
    """"""
    start: builtins.int
    """"""
    time_length: builtins.int
    """"""
    @property
    def start_toast(self) -> global___QnTrialToast:
        """"""
    @property
    def end_toast(self) -> global___QnTrialToast:
        """"""
    @property
    def quality_open_tip_btn(self) -> global___QnTrialButton:
        """"""
    def __init__(
        self,
        *,
        trial_able: builtins.bool = ...,
        remaining_times: builtins.int = ...,
        start: builtins.int = ...,
        time_length: builtins.int = ...,
        start_toast: global___QnTrialToast | None = ...,
        end_toast: global___QnTrialToast | None = ...,
        quality_open_tip_btn: global___QnTrialButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_toast", b"end_toast", "quality_open_tip_btn", b"quality_open_tip_btn", "start_toast", b"start_toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_toast", b"end_toast", "quality_open_tip_btn", b"quality_open_tip_btn", "remaining_times", b"remaining_times", "start", b"start", "start_toast", b"start_toast", "time_length", b"time_length", "trial_able", b"trial_able"]) -> None: ...

global___QnTrialInfo = QnTrialInfo

@typing_extensions.final
class QnTrialToast(google.protobuf.message.Message):
    """高画质试看信息: Toast信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    text: builtins.str
    """toast文案 老字段"""
    @property
    def button(self) -> global___QnTrialButton:
        """toast按钮"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        button: global___QnTrialButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "text", b"text"]) -> None: ...

global___QnTrialToast = QnTrialToast

@typing_extensions.final
class Event(google.protobuf.message.Message):
    """事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHAKE_FIELD_NUMBER: builtins.int
    @property
    def shake(self) -> global___Shake:
        """震动"""
    def __init__(
        self,
        *,
        shake: global___Shake | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["shake", b"shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["shake", b"shake"]) -> None: ...

global___Event = Event

@typing_extensions.final
class Shake(google.protobuf.message.Message):
    """震动"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    file: builtins.str
    """"""
    def __init__(
        self,
        *,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file"]) -> None: ...

global___Shake = Shake



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/account/fission/v1/fission.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/account/fission/v1/fission.proto\x12\x1b\x62ilibili.account.fission.v1\")\n\x0b\x41nimateIcon\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04json\x18\x02 \x01(\t\"x\n\rEntranceReply\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12>\n\x0c\x61nimate_icon\x18\x04 \x01(\x0b\x32(.bilibili.account.fission.v1.AnimateIcon\"\r\n\x0b\x45ntranceReq\"\x1f\n\x0cPrivacyReply\x12\x0f\n\x07message\x18\x01 \x01(\t\"\"\n\nPrivacyReq\x12\x14\n\x0c\x61\x63tivity_uid\x18\x01 \x01(\t\"=\n\x0bWindowReply\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x13\n\x0breport_data\x18\x03 \x01(\t\"\x0b\n\tWindowReq2\xa6\x02\n\x07\x46ission\x12`\n\x08\x45ntrance\x12(.bilibili.account.fission.v1.EntranceReq\x1a*.bilibili.account.fission.v1.EntranceReply\x12Z\n\x06Window\x12&.bilibili.account.fission.v1.WindowReq\x1a(.bilibili.account.fission.v1.WindowReply\x12]\n\x07Privacy\x12\'.bilibili.account.fission.v1.PrivacyReq\x1a).bilibili.account.fission.v1.PrivacyReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.account.fission.v1.fission_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANIMATEICON._serialized_start=74
  _ANIMATEICON._serialized_end=115
  _ENTRANCEREPLY._serialized_start=117
  _ENTRANCEREPLY._serialized_end=237
  _ENTRANCEREQ._serialized_start=239
  _ENTRANCEREQ._serialized_end=252
  _PRIVACYREPLY._serialized_start=254
  _PRIVACYREPLY._serialized_end=285
  _PRIVACYREQ._serialized_start=287
  _PRIVACYREQ._serialized_end=321
  _WINDOWREPLY._serialized_start=323
  _WINDOWREPLY._serialized_end=384
  _WINDOWREQ._serialized_start=386
  _WINDOWREQ._serialized_end=397
  _FISSION._serialized_start=400
  _FISSION._serialized_end=694
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.rpc.status_pb2
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RoomErrorEvent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> bilireq.grpc.protos.bilibili.rpc.status_pb2.Status:
        """"""
    def __init__(
        self,
        *,
        status: bilibili.rpc.status_pb2.Status | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___RoomErrorEvent = RoomErrorEvent

@typing_extensions.final
class RoomJoinEvent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RoomJoinEvent = RoomJoinEvent

@typing_extensions.final
class RoomLeaveEvent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RoomLeaveEvent = RoomLeaveEvent

@typing_extensions.final
class RoomMessageEvent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_PATH_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    target_path: builtins.str
    """"""
    @property
    def body(self) -> google.protobuf.any_pb2.Any:
        """"""
    def __init__(
        self,
        *,
        target_path: builtins.str = ...,
        body: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body", b"body"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "target_path", b"target_path"]) -> None: ...

global___RoomMessageEvent = RoomMessageEvent

@typing_extensions.final
class RoomOnlineEvent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_FIELD_NUMBER: builtins.int
    ALL_ONLINE_FIELD_NUMBER: builtins.int
    online: builtins.int
    """"""
    all_online: builtins.int
    """"""
    def __init__(
        self,
        *,
        online: builtins.int = ...,
        all_online: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_online", b"all_online", "online", b"online"]) -> None: ...

global___RoomOnlineEvent = RoomOnlineEvent

@typing_extensions.final
class RoomReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    JOIN_FIELD_NUMBER: builtins.int
    LEAVE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    id: builtins.str
    """{type}://{room_id}"""
    @property
    def join(self) -> global___RoomJoinEvent:
        """"""
    @property
    def leave(self) -> global___RoomLeaveEvent:
        """"""
    @property
    def online(self) -> global___RoomOnlineEvent:
        """"""
    @property
    def msg(self) -> global___RoomMessageEvent:
        """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        join: global___RoomJoinEvent | None = ...,
        leave: global___RoomLeaveEvent | None = ...,
        online: global___RoomOnlineEvent | None = ...,
        msg: global___RoomMessageEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event", b"event", "join", b"join", "leave", b"leave", "msg", b"msg", "online", b"online"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event", "id", b"id", "join", b"join", "leave", b"leave", "msg", b"msg", "online", b"online"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["join", "leave", "online", "msg"] | None: ...

global___RoomReq = RoomReq

@typing_extensions.final
class RoomResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    JOIN_FIELD_NUMBER: builtins.int
    LEAVE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    ERR_FIELD_NUMBER: builtins.int
    id: builtins.str
    """{type}://{room_id}"""
    @property
    def join(self) -> global___RoomJoinEvent:
        """"""
    @property
    def leave(self) -> global___RoomLeaveEvent:
        """"""
    @property
    def online(self) -> global___RoomOnlineEvent:
        """"""
    @property
    def msg(self) -> global___RoomMessageEvent:
        """"""
    @property
    def err(self) -> global___RoomErrorEvent:
        """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        join: global___RoomJoinEvent | None = ...,
        leave: global___RoomLeaveEvent | None = ...,
        online: global___RoomOnlineEvent | None = ...,
        msg: global___RoomMessageEvent | None = ...,
        err: global___RoomErrorEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["err", b"err", "event", b"event", "join", b"join", "leave", b"leave", "msg", b"msg", "online", b"online"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["err", b"err", "event", b"event", "id", b"id", "join", b"join", "leave", b"leave", "msg", b"msg", "online", b"online"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["join", "leave", "online", "msg", "err"] | None: ...

global___RoomResp = RoomResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/playurl/v1/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/playurl/v1/playurl.proto\x12\x17\x62ilibili.app.playurl.v1\"D\n\x02\x41\x42\x12/\n\x06glance\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.playurl.v1.Glance\x12\r\n\x05group\x18\x02 \x01(\x05\"m\n\x07\x41rcConf\x12\x12\n\nis_support\x18\x01 \x01(\x08\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12<\n\rextra_content\x18\x03 \x01(\x0b\x32%.bilibili.app.playurl.v1.ExtraContent\"$\n\x07\x43hronos\x12\x0b\n\x03md5\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\"T\n\x0b\x42uttonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x10\n\x08\x62g_color\x18\x03 \x01(\t\x12\x11\n\tjump_link\x18\x04 \x01(\t\"\xc1\x01\n\tCloudConf\x12\x0c\n\x04show\x18\x01 \x01(\x08\x12\x34\n\tconf_type\x18\x02 \x01(\x0e\x32!.bilibili.app.playurl.v1.ConfType\x12\x38\n\x0b\x66ield_value\x18\x03 \x01(\x0b\x32#.bilibili.app.playurl.v1.FieldValue\x12\x36\n\nconf_value\x18\x04 \x01(\x0b\x32\".bilibili.app.playurl.v1.ConfValue\"B\n\tConfValue\x12\x14\n\nswitch_val\x18\x01 \x01(\x08H\x00\x12\x16\n\x0cselected_val\x18\x02 \x01(\x03H\x00\x42\x07\n\x05value\"\xa5\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0f\n\x07\x62\x61seUrl\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x05 \x01(\r\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04size\x18\x07 \x01(\x04\x12\x12\n\nframe_rate\x18\x08 \x01(\t\x12\x15\n\rwidevine_pssh\x18\t \x01(\t\"\xdf\x01\n\tDashVideo\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x12\n\nbackup_url\x18\x02 \x03(\t\x12\x11\n\tbandwidth\x18\x03 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x04 \x01(\r\x12\x0b\n\x03md5\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x04\x12\x0f\n\x07\x61udioId\x18\x07 \x01(\r\x12\x12\n\nno_rexcode\x18\x08 \x01(\x08\x12\x12\n\nframe_rate\x18\t \x01(\t\x12\r\n\x05width\x18\n \x01(\x05\x12\x0e\n\x06height\x18\x0b \x01(\x05\x12\x15\n\rwidevine_pssh\x18\x0c \x01(\t\"\x9d\x01\n\tDolbyItem\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.app.playurl.v1.DolbyItem.Type\x12\x30\n\x05\x61udio\x18\x02 \x01(\x0b\x32!.bilibili.app.playurl.v1.DashItem\"\'\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41TMOS\x10\x02\"6\n\x05\x45vent\x12-\n\x05shake\x18\x01 \x01(\x0b\x32\x1e.bilibili.app.playurl.v1.Shake\">\n\x0c\x45xtraContent\x12\x17\n\x0f\x64isabled_reason\x18\x01 \x01(\t\x12\x15\n\rdisabled_code\x18\x02 \x01(\x03\"\'\n\nFieldValue\x12\x10\n\x06switch\x18\x01 \x01(\x08H\x00\x42\x07\n\x05value\"\x8d\x01\n\x11\x46ormatDescription\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x17\n\x0fnew_description\x18\x04 \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x05 \x01(\t\x12\x13\n\x0bsuperscript\x18\x06 \x01(\t\"<\n\x06Glance\x12\x11\n\tcan_watch\x18\x01 \x01(\x08\x12\r\n\x05times\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\"\xc9\r\n\x0fPlayAbilityConf\x12@\n\x14\x62\x61\x63kground_play_conf\x18\x01 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tflip_conf\x18\x02 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tcast_conf\x18\x03 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x39\n\rfeedback_conf\x18\x04 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x39\n\rsubtitle_conf\x18\x05 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12>\n\x12playback_rate_conf\x18\x06 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x38\n\x0ctime_up_conf\x18\x07 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12>\n\x12playback_mode_conf\x18\x08 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12;\n\x0fscale_mode_conf\x18\t \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tlike_conf\x18\n \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x38\n\x0c\x64islike_conf\x18\x0b \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tcoin_conf\x18\x0c \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\telec_conf\x18\r \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x36\n\nshare_conf\x18\x0e \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12<\n\x10screen_shot_conf\x18\x0f \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12<\n\x10lock_screen_conf\x18\x10 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12:\n\x0erecommend_conf\x18\x11 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12?\n\x13playback_speed_conf\x18\x12 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12;\n\x0f\x64\x65\x66inition_conf\x18\x13 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12;\n\x0fselections_conf\x18\x14 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tnext_conf\x18\x15 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x38\n\x0c\x65\x64it_dm_conf\x18\x16 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12=\n\x11small_window_conf\x18\x17 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x36\n\nshake_conf\x18\x18 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x39\n\router_dm_conf\x18\x19 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12:\n\x0einnerDmDisable\x18\x1a \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x39\n\rinner_dm_conf\x18\x1b \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x36\n\ndolby_conf\x18\x1c \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12=\n\x11\x63olor_filter_conf\x18\x1d \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\"\xcb\r\n\x0bPlayArcConf\x12>\n\x14\x62\x61\x63kground_play_conf\x18\x01 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tflip_conf\x18\x02 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tcast_conf\x18\x03 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\rfeedback_conf\x18\x04 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\rsubtitle_conf\x18\x05 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12<\n\x12playback_rate_conf\x18\x06 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x36\n\x0ctime_up_conf\x18\x07 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12<\n\x12playback_mode_conf\x18\x08 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x39\n\x0fscale_mode_conf\x18\t \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tlike_conf\x18\n \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x36\n\x0c\x64islike_conf\x18\x0b \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tcoin_conf\x18\x0c \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\telec_conf\x18\r \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x34\n\nshare_conf\x18\x0e \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12:\n\x10screen_shot_conf\x18\x0f \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12:\n\x10lock_screen_conf\x18\x10 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x38\n\x0erecommend_conf\x18\x11 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12=\n\x13playback_speed_conf\x18\x12 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x39\n\x0f\x64\x65\x66inition_conf\x18\x13 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x39\n\x0fselections_conf\x18\x14 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tnext_conf\x18\x15 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x36\n\x0c\x65\x64it_dm_conf\x18\x16 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12;\n\x11small_window_conf\x18\x17 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x34\n\nshake_conf\x18\x18 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\router_dm_conf\x18\x19 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\rinner_dm_conf\x18\x1a \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\rpanorama_conf\x18\x1b \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x34\n\ndolby_conf\x18\x1c \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12?\n\x15screen_recording_conf\x18\x1d \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12;\n\x11\x63olor_filter_conf\x18\x1e \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\"\x13\n\x11PlayConfEditReply\"L\n\x0fPlayConfEditReq\x12\x39\n\tplay_conf\x18\x01 \x03(\x0b\x32&.bilibili.app.playurl.v1.PlayConfState\"L\n\rPlayConfReply\x12;\n\tplay_conf\x18\x01 \x01(\x0b\x32(.bilibili.app.playurl.v1.PlayAbilityConf\"\r\n\x0bPlayConfReq\"\xc5\x01\n\rPlayConfState\x12\x34\n\tconf_type\x18\x01 \x01(\x0e\x32!.bilibili.app.playurl.v1.ConfType\x12\x0c\n\x04show\x18\x02 \x01(\x08\x12\x38\n\x0b\x66ield_value\x18\x03 \x01(\x0b\x32#.bilibili.app.playurl.v1.FieldValue\x12\x36\n\nconf_value\x18\x04 \x01(\x0b\x32\".bilibili.app.playurl.v1.ConfValue\"\x9d\x01\n\tPlayLimit\x12\x34\n\x04\x63ode\x18\x01 \x01(\x0e\x32&.bilibili.app.playurl.v1.PlayLimitCode\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0bsub_message\x18\x03 \x01(\t\x12\x34\n\x06\x62utton\x18\x04 \x01(\x0b\x32$.bilibili.app.playurl.v1.ButtonStyle\"\xc1\x03\n\x0cPlayURLReply\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\ntimelength\x18\x03 \x01(\x04\x12\x15\n\rvideo_codecid\x18\x04 \x01(\r\x12\r\n\x05\x66nver\x18\x05 \x01(\r\x12\r\n\x05\x66nval\x18\x06 \x01(\r\x12\x15\n\rvideo_project\x18\x07 \x01(\x08\x12\x32\n\x04\x64url\x18\x08 \x03(\x0b\x32$.bilibili.app.playurl.v1.ResponseUrl\x12\x33\n\x04\x64\x61sh\x18\t \x01(\x0b\x32%.bilibili.app.playurl.v1.ResponseDash\x12\x12\n\nno_rexcode\x18\n \x01(\x05\x12<\n\rupgrade_limit\x18\x0b \x01(\x0b\x32%.bilibili.app.playurl.v1.UpgradeLimit\x12\x43\n\x0fsupport_formats\x18\x0c \x03(\x0b\x32*.bilibili.app.playurl.v1.FormatDescription\x12\x30\n\x04type\x18\r \x01(\x0e\x32\".bilibili.app.playurl.v1.VideoType\"\xa8\x01\n\nPlayURLReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\"\xbd\x03\n\rPlayViewReply\x12\x36\n\nvideo_info\x18\x01 \x01(\x0b\x32\".bilibili.app.playurl.v1.VideoInfo\x12;\n\tplay_conf\x18\x02 \x01(\x0b\x32(.bilibili.app.playurl.v1.PlayAbilityConf\x12<\n\rupgrade_limit\x18\x03 \x01(\x0b\x32%.bilibili.app.playurl.v1.UpgradeLimit\x12\x31\n\x07\x63hronos\x18\x04 \x01(\x0b\x32 .bilibili.app.playurl.v1.Chronos\x12\x36\n\x08play_arc\x18\x05 \x01(\x0b\x32$.bilibili.app.playurl.v1.PlayArcConf\x12-\n\x05\x65vent\x18\x06 \x01(\x0b\x32\x1e.bilibili.app.playurl.v1.Event\x12\'\n\x02\x61\x62\x18\x07 \x01(\x0b\x32\x1b.bilibili.app.playurl.v1.AB\x12\x36\n\nplay_limit\x18\x08 \x01(\x0b\x32\".bilibili.app.playurl.v1.PlayLimit\"\xcb\x02\n\x0bPlayViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x0b \x01(\x05\x12<\n\x11prefer_codec_type\x18\x0c \x01(\x0e\x32!.bilibili.app.playurl.v1.CodeType\x12\x33\n\x08\x62usiness\x18\r \x01(\x0e\x32!.bilibili.app.playurl.v1.Business\x12\x15\n\rvoice_balance\x18\x0e \x01(\x03\"F\n\x0cProjectReply\x12\x36\n\x07project\x18\x01 \x01(\x0b\x32%.bilibili.app.playurl.v1.PlayURLReply\"\xcf\x01\n\nProjectReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x10\n\x08protocol\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x65vice_type\x18\x0c \x01(\x05\"r\n\x0cResponseDash\x12\x30\n\x05video\x18\x01 \x03(\x0b\x32!.bilibili.app.playurl.v1.DashItem\x12\x30\n\x05\x61udio\x18\x02 \x03(\x0b\x32!.bilibili.app.playurl.v1.DashItem\"h\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x12\n\nbackup_url\x18\x05 \x03(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\"E\n\x0cSegmentVideo\x12\x35\n\x07segment\x18\x01 \x03(\x0b\x32$.bilibili.app.playurl.v1.ResponseUrl\"\x15\n\x05Shake\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\xc7\x01\n\x06Stream\x12\x38\n\x0bstream_info\x18\x01 \x01(\x0b\x32#.bilibili.app.playurl.v1.StreamInfo\x12\x38\n\ndash_video\x18\x02 \x01(\x0b\x32\".bilibili.app.playurl.v1.DashVideoH\x00\x12>\n\rsegment_video\x18\x03 \x01(\x0b\x32%.bilibili.app.playurl.v1.SegmentVideoH\x00\x42\t\n\x07\x63ontent\"\xcc\x02\n\nStreamInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x32\n\x08\x65rr_code\x18\x04 \x01(\x0e\x32 .bilibili.app.playurl.v1.PlayErr\x12\x33\n\x05limit\x18\x05 \x01(\x0b\x32$.bilibili.app.playurl.v1.StreamLimit\x12\x10\n\x08need_vip\x18\x06 \x01(\x08\x12\x12\n\nneed_login\x18\x07 \x01(\x08\x12\x0e\n\x06intact\x18\x08 \x01(\x08\x12\x12\n\nno_rexcode\x18\t \x01(\x08\x12\x11\n\tattribute\x18\n \x01(\x03\x12\x17\n\x0fnew_description\x18\x0b \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x0c \x01(\t\x12\x13\n\x0bsuperscript\x18\r \x01(\t\"6\n\x0bStreamLimit\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\",\n\rUpgradeButton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"t\n\x0cUpgradeLimit\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x36\n\x06\x62utton\x18\x04 \x01(\x0b\x32&.bilibili.app.playurl.v1.UpgradeButton\"\xac\x02\n\tVideoInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\ntimelength\x18\x03 \x01(\x04\x12\x15\n\rvideo_codecid\x18\x04 \x01(\r\x12\x34\n\x0bstream_list\x18\x05 \x03(\x0b\x32\x1f.bilibili.app.playurl.v1.Stream\x12\x35\n\ndash_audio\x18\x06 \x03(\x0b\x32!.bilibili.app.playurl.v1.DashItem\x12\x31\n\x05\x64olby\x18\x07 \x01(\x0b\x32\".bilibili.app.playurl.v1.DolbyItem\x12\x33\n\x06volume\x18\x08 \x01(\x0b\x32#.bilibili.app.playurl.v1.VolumeInfo\"\xa3\x01\n\nVolumeInfo\x12\x12\n\nmeasured_i\x18\x01 \x01(\x01\x12\x14\n\x0cmeasured_lra\x18\x02 \x01(\x01\x12\x13\n\x0bmeasured_tp\x18\x03 \x01(\x01\x12\x1a\n\x12measured_threshold\x18\x04 \x01(\x01\x12\x15\n\rtarget_offset\x18\x05 \x01(\x01\x12\x10\n\x08target_i\x18\x06 \x01(\x01\x12\x11\n\ttarget_tp\x18\x07 \x01(\x01*\"\n\x08\x42usiness\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05STORY\x10\x01*=\n\x08\x43odeType\x12\n\n\x06NOCODE\x10\x00\x12\x0b\n\x07\x43ODE264\x10\x01\x12\x0b\n\x07\x43ODE265\x10\x02\x12\x0b\n\x07\x43ODEAV1\x10\x03*\xaf\x03\n\x08\x43onfType\x12\n\n\x06NoType\x10\x00\x12\x0c\n\x08\x46LIPCONF\x10\x01\x12\x0c\n\x08\x43\x41STCONF\x10\x02\x12\x0c\n\x08\x46\x45\x45\x44\x42\x41\x43K\x10\x03\x12\x0c\n\x08SUBTITLE\x10\x04\x12\x10\n\x0cPLAYBACKRATE\x10\x05\x12\n\n\x06TIMEUP\x10\x06\x12\x10\n\x0cPLAYBACKMODE\x10\x07\x12\r\n\tSCALEMODE\x10\x08\x12\x12\n\x0e\x42\x41\x43KGROUNDPLAY\x10\t\x12\x08\n\x04LIKE\x10\n\x12\x0b\n\x07\x44ISLIKE\x10\x0b\x12\x08\n\x04\x43OIN\x10\x0c\x12\x08\n\x04\x45LEC\x10\r\x12\t\n\x05SHARE\x10\x0e\x12\x0e\n\nSCREENSHOT\x10\x0f\x12\x0e\n\nLOCKSCREEN\x10\x10\x12\r\n\tRECOMMEND\x10\x11\x12\x11\n\rPLAYBACKSPEED\x10\x12\x12\x0e\n\nDEFINITION\x10\x13\x12\x0e\n\nSELECTIONS\x10\x14\x12\x08\n\x04NEXT\x10\x15\x12\n\n\x06\x45\x44ITDM\x10\x16\x12\x0f\n\x0bSMALLWINDOW\x10\x17\x12\t\n\x05SHAKE\x10\x18\x12\x0b\n\x07OUTERDM\x10\x19\x12\x0b\n\x07INNERDM\x10\x1a\x12\x0c\n\x08PANORAMA\x10\x1b\x12\t\n\x05\x44OLBY\x10\x1c\x12\x0f\n\x0b\x43OLORFILTER\x10\x1d*.\n\x05Group\x12\x10\n\x0cUnknownGroup\x10\x00\x12\x05\n\x01\x41\x10\x01\x12\x05\n\x01\x42\x10\x02\x12\x05\n\x01\x43\x10\x03*1\n\x07PlayErr\x12\t\n\x05NoErr\x10\x00\x12\x1b\n\x17WithMultiDeviceLoginErr\x10\x01*2\n\rPlayLimitCode\x12\r\n\tPLCUnkown\x10\x00\x12\x12\n\x0ePLCUgcNotPayed\x10\x01*L\n\tVideoType\x12\x11\n\rUnknown_VALUE\x10\x00\x12\r\n\tFLV_VALUE\x10\x01\x12\x0e\n\nDASH_VALUE\x10\x02\x12\r\n\tMP4_VALUE\x10\x03\x32\xd1\x03\n\x07PlayURL\x12U\n\x07PlayURL\x12#.bilibili.app.playurl.v1.PlayURLReq\x1a%.bilibili.app.playurl.v1.PlayURLReply\x12U\n\x07Project\x12#.bilibili.app.playurl.v1.ProjectReq\x1a%.bilibili.app.playurl.v1.ProjectReply\x12X\n\x08PlayView\x12$.bilibili.app.playurl.v1.PlayViewReq\x1a&.bilibili.app.playurl.v1.PlayViewReply\x12\x64\n\x0cPlayConfEdit\x12(.bilibili.app.playurl.v1.PlayConfEditReq\x1a*.bilibili.app.playurl.v1.PlayConfEditReply\x12X\n\x08PlayConf\x12$.bilibili.app.playurl.v1.PlayConfReq\x1a&.bilibili.app.playurl.v1.PlayConfReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.playurl.v1.playurl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUSINESS._serialized_start=8819
  _BUSINESS._serialized_end=8853
  _CODETYPE._serialized_start=8855
  _CODETYPE._serialized_end=8916
  _CONFTYPE._serialized_start=8919
  _CONFTYPE._serialized_end=9350
  _GROUP._serialized_start=9352
  _GROUP._serialized_end=9398
  _PLAYERR._serialized_start=9400
  _PLAYERR._serialized_end=9449
  _PLAYLIMITCODE._serialized_start=9451
  _PLAYLIMITCODE._serialized_end=9501
  _VIDEOTYPE._serialized_start=9503
  _VIDEOTYPE._serialized_end=9579
  _AB._serialized_start=66
  _AB._serialized_end=134
  _ARCCONF._serialized_start=136
  _ARCCONF._serialized_end=245
  _CHRONOS._serialized_start=247
  _CHRONOS._serialized_end=283
  _BUTTONSTYLE._serialized_start=285
  _BUTTONSTYLE._serialized_end=369
  _CLOUDCONF._serialized_start=372
  _CLOUDCONF._serialized_end=565
  _CONFVALUE._serialized_start=567
  _CONFVALUE._serialized_end=633
  _DASHITEM._serialized_start=636
  _DASHITEM._serialized_end=801
  _DASHVIDEO._serialized_start=804
  _DASHVIDEO._serialized_end=1027
  _DOLBYITEM._serialized_start=1030
  _DOLBYITEM._serialized_end=1187
  _DOLBYITEM_TYPE._serialized_start=1148
  _DOLBYITEM_TYPE._serialized_end=1187
  _EVENT._serialized_start=1189
  _EVENT._serialized_end=1243
  _EXTRACONTENT._serialized_start=1245
  _EXTRACONTENT._serialized_end=1307
  _FIELDVALUE._serialized_start=1309
  _FIELDVALUE._serialized_end=1348
  _FORMATDESCRIPTION._serialized_start=1351
  _FORMATDESCRIPTION._serialized_end=1492
  _GLANCE._serialized_start=1494
  _GLANCE._serialized_end=1554
  _PLAYABILITYCONF._serialized_start=1557
  _PLAYABILITYCONF._serialized_end=3294
  _PLAYARCCONF._serialized_start=3297
  _PLAYARCCONF._serialized_end=5036
  _PLAYCONFEDITREPLY._serialized_start=5038
  _PLAYCONFEDITREPLY._serialized_end=5057
  _PLAYCONFEDITREQ._serialized_start=5059
  _PLAYCONFEDITREQ._serialized_end=5135
  _PLAYCONFREPLY._serialized_start=5137
  _PLAYCONFREPLY._serialized_end=5213
  _PLAYCONFREQ._serialized_start=5215
  _PLAYCONFREQ._serialized_end=5228
  _PLAYCONFSTATE._serialized_start=5231
  _PLAYCONFSTATE._serialized_end=5428
  _PLAYLIMIT._serialized_start=5431
  _PLAYLIMIT._serialized_end=5588
  _PLAYURLREPLY._serialized_start=5591
  _PLAYURLREPLY._serialized_end=6040
  _PLAYURLREQ._serialized_start=6043
  _PLAYURLREQ._serialized_end=6211
  _PLAYVIEWREPLY._serialized_start=6214
  _PLAYVIEWREPLY._serialized_end=6659
  _PLAYVIEWREQ._serialized_start=6662
  _PLAYVIEWREQ._serialized_end=6993
  _PROJECTREPLY._serialized_start=6995
  _PROJECTREPLY._serialized_end=7065
  _PROJECTREQ._serialized_start=7068
  _PROJECTREQ._serialized_end=7275
  _RESPONSEDASH._serialized_start=7277
  _RESPONSEDASH._serialized_end=7391
  _RESPONSEURL._serialized_start=7393
  _RESPONSEURL._serialized_end=7497
  _SEGMENTVIDEO._serialized_start=7499
  _SEGMENTVIDEO._serialized_end=7568
  _SHAKE._serialized_start=7570
  _SHAKE._serialized_end=7591
  _STREAM._serialized_start=7594
  _STREAM._serialized_end=7793
  _STREAMINFO._serialized_start=7796
  _STREAMINFO._serialized_end=8128
  _STREAMLIMIT._serialized_start=8130
  _STREAMLIMIT._serialized_end=8184
  _UPGRADEBUTTON._serialized_start=8186
  _UPGRADEBUTTON._serialized_end=8230
  _UPGRADELIMIT._serialized_start=8232
  _UPGRADELIMIT._serialized_end=8348
  _VIDEOINFO._serialized_start=8351
  _VIDEOINFO._serialized_end=8651
  _VOLUMEINFO._serialized_start=8654
  _VOLUMEINFO._serialized_end=8817
  _PLAYURL._serialized_start=9582
  _PLAYURL._serialized_end=10047
# @@protoc_insertion_point(module_scope)



import asyncio
import io
from base64 import b64encode
from typing import Optional, Union

from .._typing import T_Auth
from ..auth import Auth
from ..exceptions import ResponseCodeError
from ..utils import get, post
from .pwd_login import pwd_login as _pwd_login
from .qrcode_login import get_qrcode_login_info, get_qrcode_login_result
from .sms_login import send_sms
from .sms_login import sms_login as _sms_login

BASE_URL = "https://passport.bilibili.com/api/v2/oauth2/"


async def refresh_token(auth: T_Auth = None, *, reqtype="app", **kwargs):
    """
    刷新 Token

    Args:
        access_token (str): Access Token
        refresh_token (str): Refresh Token

    Raises:
        ResponseCodeError: 返回码不为 0

    Returns:
        Dict: 刷新后的 Token 信息，原 Token 失效
    """
    url = f"{BASE_URL}refresh_token"
    return await post(url, auth=auth, reqtype=reqtype, **kwargs)


async def get_token_info(auth: T_Auth = None, *, reqtype="app", **kwargs):
    """
    获取 Token 登录信息

    Args:
        access_token (str): Access Token

    Raises:
        ResponseCodeError: 返回码不为 0
            -101: user not login

    Returns:
        Dict: Token 信息
    """
    url = f"{BASE_URL}info"
    return await get(url, auth=auth, reqtype=reqtype, **kwargs)


class Login:
    auth_code: str
    qrcode_url: str
    tel: int
    cid: int
    captcha_key: str

    async def get_qrcode_url(self) -> str:
        r = await get_qrcode_login_info()
        self.auth_code = r["auth_code"]
        self.qrcode_url = r["url"]
        return self.qrcode_url

    async def get_qrcode(self, url: Optional[str] = None, print_=False, base64=False):
        try:
            import qrcode  # type: ignore
        except ImportError:
            raise ImportError("bilireq[qrcode] not installed.")
        url = url or await self.get_qrcode_url()
        qr = qrcode.QRCode()
        qr.add_data(url)
        if print_:
            qr.print_tty()
            return None
        img = qr.make_image()
        if not base64:
            return img
        buf = io.BytesIO()
        img.save(buf, format="PNG")
        return b64encode(buf.getvalue()).decode()

    async def qrcode_login(self, auth_code=None, retry=-1, interval=1):
        auth_code = auth_code or self.auth_code
        while retry:
            try:
                resp = await get_qrcode_login_result(auth_code)
                auth = Auth()
                auth.access_token = resp["token_info"]["access_token"]
                auth.refresh_token = resp["token_info"]["refresh_token"]
                return await auth.refresh()
            except ResponseCodeError as e:
                if e.code != 86039:
                    raise
            await asyncio.sleep(interval)
            retry -= 1

    async def send_sms(self, tel, cid=86) -> str:
        self.tel = tel
        self.cid = cid
        self.captcha_key: str = (await send_sms(tel, cid=cid))["captcha_key"]
        return self.captcha_key

    async def sms_login(
        self,
        code: Union[int, str],
        tel: Union[int, str, None] = None,
        cid: Union[int, str, None] = None,
        captcha_key: Optional[str] = None,
    ):
        resp = await _sms_login(
            code=code,
            tel=tel or self.tel,
            cid=cid or self.cid,
            captcha_key=captcha_key or self.captcha_key,
        )
        auth = Auth()
        auth.access_token = resp["access_token"]
        auth.refresh_token = resp["refresh_token"]
        return await auth.refresh()

    async def pwd_login(self, username: str, password: str):
        resp = await _pwd_login(username, password)
        auth = Auth()
        auth.access_token = resp["access_token"]
        auth.refresh_token = resp["refresh_token"]
        return await auth.refresh()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/gaia/gw/gw_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x62ilibili/gaia/gw/gw_api.proto\x12\x10\x62ilibili.gaia.gw\x1a\x1bgoogle/protobuf/empty.proto\"O\n\rDeviceAppList\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x17\n\x0fsystem_app_list\x18\x02 \x03(\t\x12\x15\n\ruser_app_list\x18\x03 \x03(\t\"L\n\x13\x46\x65tchPublicKeyReply\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x03 \x01(\x03\"\xe7\x02\n\x13GaiaDeviceBasicInfo\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x10\n\x08mobi_app\x18\x03 \x01(\t\x12\x0e\n\x06origin\x18\x04 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x05 \x01(\t\x12\x0e\n\x06sdkver\x18\x06 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x07 \x01(\t\x12\x18\n\x10\x61pp_version_code\x18\x08 \x01(\t\x12\r\n\x05\x62uild\x18\t \x01(\t\x12\x0f\n\x07\x63hannel\x18\n \x01(\t\x12\r\n\x05\x62rand\x18\x0b \x01(\t\x12\r\n\x05model\x18\x0c \x01(\t\x12\r\n\x05osver\x18\r \x01(\t\x12\x12\n\nuser_agent\x18\x0e \x01(\t\x12\x13\n\x0b\x62uvid_local\x18\x0f \x01(\t\x12\r\n\x05\x62uvid\x18\x10 \x01(\t\x12\x0b\n\x03mid\x18\x11 \x01(\t\x12\x0b\n\x03\x66ts\x18\x12 \x01(\x03\x12\r\n\x05\x66irst\x18\x13 \x01(\x05\x12\x0f\n\x07network\x18\x14 \x01(\t\"]\n\x11GaiaEncryptMsgReq\x12/\n\x06header\x18\x01 \x01(\x0b\x32\x1f.bilibili.gaia.gw.GaiaMsgHeader\x12\x17\n\x0f\x65ncrypt_payload\x18\x02 \x01(\x0c\"\x9d\x01\n\rGaiaMsgHeader\x12\x32\n\x0b\x65ncode_type\x18\x01 \x01(\x0e\x32\x1d.bilibili.gaia.gw.EncryptType\x12\x33\n\x0cpayload_type\x18\x02 \x01(\x0e\x32\x1d.bilibili.gaia.gw.PayloadType\x12\x17\n\x0f\x65ncoded_aes_key\x18\x03 \x01(\x0c\x12\n\n\x02ts\x18\x04 \x01(\x03\"&\n\x12UploadAppListReply\x12\x10\n\x08trace_id\x18\x01 \x01(\t*K\n\x0b\x45ncryptType\x12\x18\n\x14INVALID_ENCRYPT_TYPE\x10\x00\x12\x0e\n\nCLIENT_AES\x10\x01\x12\x12\n\x0eSERVER_RSA_AES\x10\x02*7\n\x0bPayloadType\x12\x13\n\x0fINVALID_PAYLOAD\x10\x00\x12\x13\n\x0f\x44\x45VICE_APP_LIST\x10\x01\x32\xb7\x01\n\x04Gaia\x12\\\n\x0f\x45xUploadAppList\x12#.bilibili.gaia.gw.GaiaEncryptMsgReq\x1a$.bilibili.gaia.gw.UploadAppListReply\x12Q\n\x10\x45xFetchPublicKey\x12\x16.google.protobuf.Empty\x1a%.bilibili.gaia.gw.FetchPublicKeyReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.gaia.gw.gw_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENCRYPTTYPE._serialized_start=896
  _ENCRYPTTYPE._serialized_end=971
  _PAYLOADTYPE._serialized_start=973
  _PAYLOADTYPE._serialized_end=1028
  _DEVICEAPPLIST._serialized_start=80
  _DEVICEAPPLIST._serialized_end=159
  _FETCHPUBLICKEYREPLY._serialized_start=161
  _FETCHPUBLICKEYREPLY._serialized_end=237
  _GAIADEVICEBASICINFO._serialized_start=240
  _GAIADEVICEBASICINFO._serialized_end=599
  _GAIAENCRYPTMSGREQ._serialized_start=601
  _GAIAENCRYPTMSGREQ._serialized_end=694
  _GAIAMSGHEADER._serialized_start=697
  _GAIAMSGHEADER._serialized_end=854
  _UPLOADAPPLISTREPLY._serialized_start=856
  _UPLOADAPPLISTREPLY._serialized_end=894
  _GAIA._serialized_start=1031
  _GAIA._serialized_end=1214
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ModeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NORMAL: _ModeType.ValueType  # 0
    """正常模式"""
    TEENAGERS: _ModeType.ValueType  # 1
    """青少年模式"""
    LESSONS: _ModeType.ValueType  # 2
    """课堂模式"""

class ModeType(_ModeType, metaclass=_ModeTypeEnumTypeWrapper):
    """模式类型"""

NORMAL: ModeType.ValueType  # 0
"""正常模式"""
TEENAGERS: ModeType.ValueType  # 1
"""青少年模式"""
LESSONS: ModeType.ValueType  # 2
"""课堂模式"""
global___ModeType = ModeType

@typing_extensions.final
class Restriction(google.protobuf.message.Message):
    """限制条件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    REVIEW_FIELD_NUMBER: builtins.int
    DISABLE_RCMD_FIELD_NUMBER: builtins.int
    teenagers_mode: builtins.bool
    """青少年模式开关状态"""
    lessons_mode: builtins.bool
    """课堂模式开关状态"""
    mode: global___ModeType.ValueType
    """模式类型(旧版)"""
    review: builtins.bool
    """app 审核review状态"""
    disable_rcmd: builtins.bool
    """客户端是否选择关闭个性化推荐"""
    def __init__(
        self,
        *,
        teenagers_mode: builtins.bool = ...,
        lessons_mode: builtins.bool = ...,
        mode: global___ModeType.ValueType = ...,
        review: builtins.bool = ...,
        disable_rcmd: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_rcmd", b"disable_rcmd", "lessons_mode", b"lessons_mode", "mode", b"mode", "review", b"review", "teenagers_mode", b"teenagers_mode"]) -> None: ...

global___Restriction = Restriction



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PlayViewReq(google.protobuf.message.Message):
    """播放页信息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """课程epid(与番剧不互通)"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    spmid: builtins.str
    """当前页spm"""
    from_spmid: builtins.str
    """上一页spm"""
    teenagers_mode: builtins.int
    """青少年模式"""
    prefer_codec_type: bilibili.app.playurl.v1.playurl_pb2.CodeType.ValueType
    """视频编码"""
    is_preview: builtins.bool
    """是否强制请求预览视频"""
    def __init__(
        self,
        *,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        teenagers_mode: builtins.int = ...,
        prefer_codec_type: bilibili.app.playurl.v1.playurl_pb2.CodeType.ValueType = ...,
        is_preview: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "download", b"download", "ep_id", b"ep_id", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "from_spmid", b"from_spmid", "is_preview", b"is_preview", "prefer_codec_type", b"prefer_codec_type", "qn", b"qn", "spmid", b"spmid", "teenagers_mode", b"teenagers_mode"]) -> None: ...

global___PlayViewReq = PlayViewReq

@typing_extensions.final
class ProjectReq(google.protobuf.message.Message):
    """投屏地址-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    FLV_PROJ_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """课程epid(与番剧不互通)"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    spmid: builtins.str
    """当前页spm"""
    from_spmid: builtins.str
    """上一页spm"""
    protocol: builtins.int
    """投屏协议
    0:默认乐播 1:自建协议 2:云投屏
    """
    device_type: builtins.int
    """投屏设备
    0:默认其他 1:OTT设备
    """
    flv_proj: builtins.bool
    """是否flv格式"""
    def __init__(
        self,
        *,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        protocol: builtins.int = ...,
        device_type: builtins.int = ...,
        flv_proj: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "device_type", b"device_type", "download", b"download", "ep_id", b"ep_id", "flv_proj", b"flv_proj", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "from_spmid", b"from_spmid", "protocol", b"protocol", "qn", b"qn", "spmid", b"spmid"]) -> None: ...

global___ProjectReq = ProjectReq

@typing_extensions.final
class PlayViewReply(google.protobuf.message.Message):
    """播放页信息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_INFO_FIELD_NUMBER: builtins.int
    PLAY_CONF_FIELD_NUMBER: builtins.int
    @property
    def video_info(self) -> bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.VideoInfo:
        """视频url信息"""
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """禁用功能配置"""
    def __init__(
        self,
        *,
        video_info: bilibili.app.playurl.v1.playurl_pb2.VideoInfo | None = ...,
        play_conf: global___PlayAbilityConf | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_conf", b"play_conf", "video_info", b"video_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_conf", b"play_conf", "video_info", b"video_info"]) -> None: ...

global___PlayViewReply = PlayViewReply

@typing_extensions.final
class PlayAbilityConf(google.protobuf.message.Message):
    """禁用功能配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_PLAY_DISABLE_FIELD_NUMBER: builtins.int
    FLIP_DISABLE_FIELD_NUMBER: builtins.int
    CAST_DISABLE_FIELD_NUMBER: builtins.int
    FEEDBACK_DISABLE_FIELD_NUMBER: builtins.int
    SUBTITLE_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_DISABLE_FIELD_NUMBER: builtins.int
    TIME_UP_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_DISABLE_FIELD_NUMBER: builtins.int
    SCALE_MODE_DISABLE_FIELD_NUMBER: builtins.int
    LIKE_DISABLE_FIELD_NUMBER: builtins.int
    DISLIKE_DISABLE_FIELD_NUMBER: builtins.int
    COIN_DISABLE_FIELD_NUMBER: builtins.int
    ELEC_DISABLE_FIELD_NUMBER: builtins.int
    SHARE_DISABLE_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_DISABLE_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_DISABLE_FIELD_NUMBER: builtins.int
    RECOMMEND_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_DISABLE_FIELD_NUMBER: builtins.int
    DEFINITION_DISABLE_FIELD_NUMBER: builtins.int
    SELECTIONS_DISABLE_FIELD_NUMBER: builtins.int
    NEXT_DISABLE_FIELD_NUMBER: builtins.int
    EDIT_DM_DISABLE_FIELD_NUMBER: builtins.int
    OUTER_DM_DISABLE_FIELD_NUMBER: builtins.int
    INNER_DM_DISABLE_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_DISABLE_FIELD_NUMBER: builtins.int
    background_play_disable: builtins.bool
    """后台播放"""
    flip_disable: builtins.bool
    """镜像反转"""
    cast_disable: builtins.bool
    """支持投屏"""
    feedback_disable: builtins.bool
    """反馈"""
    subtitle_disable: builtins.bool
    """字幕"""
    playback_rate_disable: builtins.bool
    """播放速度"""
    time_up_disable: builtins.bool
    """定时停止播放"""
    playback_mode_disable: builtins.bool
    """播放方式"""
    scale_mode_disable: builtins.bool
    """画面尺寸"""
    like_disable: builtins.bool
    """顶"""
    dislike_disable: builtins.bool
    """踩"""
    coin_disable: builtins.bool
    """投币"""
    elec_disable: builtins.bool
    """充电"""
    share_disable: builtins.bool
    """分享"""
    screen_shot_disable: builtins.bool
    """截图"""
    lock_screen_disable: builtins.bool
    """锁屏"""
    recommend_disable: builtins.bool
    """相关推荐"""
    playback_speed_disable: builtins.bool
    """倍速"""
    definition_disable: builtins.bool
    """清晰度"""
    selections_disable: builtins.bool
    """选集"""
    next_disable: builtins.bool
    """下一集"""
    edit_dm_disable: builtins.bool
    """编辑弹幕"""
    outer_dm_disable: builtins.bool
    """外层面板弹幕设置"""
    inner_dm_disable: builtins.bool
    """三点内弹幕设置"""
    small_window_disable: builtins.bool
    """画中画"""
    def __init__(
        self,
        *,
        background_play_disable: builtins.bool = ...,
        flip_disable: builtins.bool = ...,
        cast_disable: builtins.bool = ...,
        feedback_disable: builtins.bool = ...,
        subtitle_disable: builtins.bool = ...,
        playback_rate_disable: builtins.bool = ...,
        time_up_disable: builtins.bool = ...,
        playback_mode_disable: builtins.bool = ...,
        scale_mode_disable: builtins.bool = ...,
        like_disable: builtins.bool = ...,
        dislike_disable: builtins.bool = ...,
        coin_disable: builtins.bool = ...,
        elec_disable: builtins.bool = ...,
        share_disable: builtins.bool = ...,
        screen_shot_disable: builtins.bool = ...,
        lock_screen_disable: builtins.bool = ...,
        recommend_disable: builtins.bool = ...,
        playback_speed_disable: builtins.bool = ...,
        definition_disable: builtins.bool = ...,
        selections_disable: builtins.bool = ...,
        next_disable: builtins.bool = ...,
        edit_dm_disable: builtins.bool = ...,
        outer_dm_disable: builtins.bool = ...,
        inner_dm_disable: builtins.bool = ...,
        small_window_disable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_disable", b"background_play_disable", "cast_disable", b"cast_disable", "coin_disable", b"coin_disable", "definition_disable", b"definition_disable", "dislike_disable", b"dislike_disable", "edit_dm_disable", b"edit_dm_disable", "elec_disable", b"elec_disable", "feedback_disable", b"feedback_disable", "flip_disable", b"flip_disable", "inner_dm_disable", b"inner_dm_disable", "like_disable", b"like_disable", "lock_screen_disable", b"lock_screen_disable", "next_disable", b"next_disable", "outer_dm_disable", b"outer_dm_disable", "playback_mode_disable", b"playback_mode_disable", "playback_rate_disable", b"playback_rate_disable", "playback_speed_disable", b"playback_speed_disable", "recommend_disable", b"recommend_disable", "scale_mode_disable", b"scale_mode_disable", "screen_shot_disable", b"screen_shot_disable", "selections_disable", b"selections_disable", "share_disable", b"share_disable", "small_window_disable", b"small_window_disable", "subtitle_disable", b"subtitle_disable", "time_up_disable", b"time_up_disable"]) -> None: ...

global___PlayAbilityConf = PlayAbilityConf

@typing_extensions.final
class ProjectReply(google.protobuf.message.Message):
    """投屏地址-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def project(self) -> bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.PlayURLReply: ...
    def __init__(
        self,
        *,
        project: bilibili.app.playurl.v1.playurl_pb2.PlayURLReply | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["project", b"project"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project", b"project"]) -> None: ...

global___ProjectReply = ProjectReply



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/mod.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x62ilibili/broadcast/v1/mod.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x1bgoogle/protobuf/empty.proto\"\x88\x01\n\x0fModResourceResp\x12\x0e\n\x06\x61tcion\x18\x01 \x01(\x05\x12\x0f\n\x07\x61pp_key\x18\x02 \x01(\t\x12\x11\n\tpool_name\x18\x03 \x01(\t\x12\x13\n\x0bmodule_name\x18\x04 \x01(\t\x12\x16\n\x0emodule_version\x18\x05 \x01(\x03\x12\x14\n\x0clist_version\x18\x06 \x01(\x03\x32_\n\nModManager\x12Q\n\rWatchResource\x12\x16.google.protobuf.Empty\x1a&.bilibili.broadcast.v1.ModResourceResp0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.v1.mod_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MODRESOURCERESP._serialized_start=88
  _MODRESOURCERESP._serialized_end=224
  _MODMANAGER._serialized_start=226
  _MODMANAGER._serialized_end=321
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.interfaces.v1 import history_pb2 as bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2


class HistoryStub(object):
    """历史记录
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HistoryTab = channel.unary_unary(
                '/bilibili.app.interface.v1.History/HistoryTab',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.HistoryTabReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.HistoryTabReply.FromString,
                )
        self.Cursor = channel.unary_unary(
                '/bilibili.app.interface.v1.History/Cursor',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorReply.FromString,
                )
        self.CursorV2 = channel.unary_unary(
                '/bilibili.app.interface.v1.History/CursorV2',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorV2Req.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorV2Reply.FromString,
                )
        self.Delete = channel.unary_unary(
                '/bilibili.app.interface.v1.History/Delete',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.DeleteReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.NoReply.FromString,
                )
        self.Search = channel.unary_unary(
                '/bilibili.app.interface.v1.History/Search',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.SearchReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.SearchReply.FromString,
                )
        self.Clear = channel.unary_unary(
                '/bilibili.app.interface.v1.History/Clear',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.ClearReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.NoReply.FromString,
                )
        self.LatestHistory = channel.unary_unary(
                '/bilibili.app.interface.v1.History/LatestHistory',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.LatestHistoryReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.LatestHistoryReply.FromString,
                )


class HistoryServicer(object):
    """历史记录
    """

    def HistoryTab(self, request, context):
        """获取历史记录tab
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cursor(self, request, context):
        """获取历史记录列表(旧版)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CursorV2(self, request, context):
        """获取历史记录列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """删除历史记录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Search(self, request, context):
        """搜索历史记录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Clear(self, request, context):
        """清空历史记录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LatestHistory(self, request, context):
        """获取最新的历史记录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HistoryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HistoryTab': grpc.unary_unary_rpc_method_handler(
                    servicer.HistoryTab,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.HistoryTabReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.HistoryTabReply.SerializeToString,
            ),
            'Cursor': grpc.unary_unary_rpc_method_handler(
                    servicer.Cursor,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorReply.SerializeToString,
            ),
            'CursorV2': grpc.unary_unary_rpc_method_handler(
                    servicer.CursorV2,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorV2Req.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorV2Reply.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.DeleteReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.NoReply.SerializeToString,
            ),
            'Search': grpc.unary_unary_rpc_method_handler(
                    servicer.Search,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.SearchReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.SearchReply.SerializeToString,
            ),
            'Clear': grpc.unary_unary_rpc_method_handler(
                    servicer.Clear,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.ClearReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.NoReply.SerializeToString,
            ),
            'LatestHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.LatestHistory,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.LatestHistoryReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.LatestHistoryReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.interface.v1.History', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class History(object):
    """历史记录
    """

    @staticmethod
    def HistoryTab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.History/HistoryTab',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.HistoryTabReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.HistoryTabReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Cursor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.History/Cursor',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CursorV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.History/CursorV2',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorV2Req.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.CursorV2Reply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.History/Delete',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.DeleteReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.History/Search',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.SearchReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.SearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Clear(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.History/Clear',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.ClearReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LatestHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.History/LatestHistory',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.LatestHistoryReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_history__pb2.LatestHistoryReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Union

from ..utils import post

BASE_URL = "https://passport.bilibili.com/x/passport-tv-login/"


async def send_sms(tel: Union[int, str], cid: Union[int, str] = 86, **kwargs):
    """
    发送短信验证码

    Args:
        tel (int): 手机号
        cid (int, optional): 区号，默认 86

    Raises:
        ResponseCodeError: 返回码不为 0
            -400: 请求错误
            66031: 手机号码格式不正确
            86046: 请使用中国大陆手机号
            86200: 短信请求过快，请60秒后重试

    Returns:
        captcha_key (str): 验证码秘钥
    """
    url = f"{BASE_URL}sms/send"
    params = {"tel": tel, "cid": cid}
    return await post(url, params=params, reqtype="app", **kwargs)


async def sms_login(
    code: Union[int, str],
    tel: Union[int, str],
    captcha_key: str,
    cid: Union[int, str] = 86,
    **kwargs,
):
    """
    短信验证码登录

    Args:
        code (Union[int, str]): 验证码
        tel (Union[int, str]): 手机号
        captcha_key (str): 验证码秘钥
        cid (Union[int, str]): 区号，默认 86

    Raises:
        ResponseCodeError: 返回码不为 0
            -400: 请求错误
            -500: 服务器错误
            86202: 验证码错误
            86205: 验证码失效，请重新获取（错误次数过多或秘钥超时）
            86206: 区号不一致，请重新确认
            86207: 手机号不一致，请重新确认

    Returns:
        Dict: 登录 Tokens
    """
    url = f"{BASE_URL}login/sms"
    params = {"code": code, "tel": tel, "cid": cid, "captcha_key": captcha_key}
    return await post(url, params=params, reqtype="app", **kwargs)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TopActivityReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    @property
    def online(self) -> global___TopOnline:
        """当前生效的资源"""
    hash: builtins.str
    """对online内容进行hash和上次结果一样则不重新加载"""
    def __init__(
        self,
        *,
        online: global___TopOnline | None = ...,
        hash: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["online", b"online"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "online", b"online"]) -> None: ...

global___TopActivityReply = TopActivityReply

@typing_extensions.final
class TopOnline(google.protobuf.message.Message):
    """当前生效的资源"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    ANIMATE_FIELD_NUMBER: builtins.int
    RED_DOT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """活动类型
    1:七日活动 2:后台配置
    """
    icon: builtins.str
    """图标"""
    uri: builtins.str
    """跳转链接"""
    unique_id: builtins.str
    """资源状态标识(后台配置)"""
    @property
    def animate(self) -> global___Animate:
        """动画资源"""
    @property
    def red_dot(self) -> global___RedDot:
        """红点"""
    name: builtins.str
    """活动名称"""
    interval: builtins.int
    """轮询间隔 单位秒"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        icon: builtins.str = ...,
        uri: builtins.str = ...,
        unique_id: builtins.str = ...,
        animate: global___Animate | None = ...,
        red_dot: global___RedDot | None = ...,
        name: builtins.str = ...,
        interval: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["animate", b"animate", "red_dot", b"red_dot"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animate", b"animate", "icon", b"icon", "interval", b"interval", "name", b"name", "red_dot", b"red_dot", "type", b"type", "unique_id", b"unique_id", "uri", b"uri"]) -> None: ...

global___TopOnline = TopOnline

@typing_extensions.final
class Animate(google.protobuf.message.Message):
    """动画资源"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    SVG_FIELD_NUMBER: builtins.int
    LOOP_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """动效结束展示icon"""
    json: builtins.str
    """7日活动动画"""
    svg: builtins.str
    """s10活动svg动画"""
    loop: builtins.int
    """循环次数(默认0不返回 表示无限循环)"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        json: builtins.str = ...,
        svg: builtins.str = ...,
        loop: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "json", b"json", "loop", b"loop", "svg", b"svg"]) -> None: ...

global___Animate = Animate

@typing_extensions.final
class RedDot(google.protobuf.message.Message):
    """红点"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    type: builtins.int
    """红点类型
    1:纯红点 2:数字红点
    """
    number: builtins.int
    """如果是数字红点 显示的数字"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["number", b"number", "type", b"type"]) -> None: ...

global___RedDot = RedDot
